@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 # ABSTRACT: parse XLSX files
 
-use Archive::Zip;
+use Archive::Zip 1.34;
 use Graphics::ColorUtils 'rgb2hls', 'hls2rgb';
 use Scalar::Util 'openhandle';
 use Spreadsheet::ParseExcel;
@@ -1161,7 +1161,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -1318,7 +1318,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexey Mazurin Daryl Anderman Dave Clarke Fitz Elliott FL Gareth Tunley Meredith Howard Michael Daum Nick Moore oharakouhei rdboisvert Ricardo Signes Robert Boisvert Steve Simms Stuart Watt theevilapplepie zhouzhen1
+=for stopwords Alexey Mazurin Daryl Anderman Dave Clarke Fitz Elliott FL Gareth Tunley M Conrad Meredith Howard Michael Daum Nick Moore oharakouhei rdboisvert Ricardo Signes Robert Boisvert Steve Simms Stuart Watt theevilapplepie zhouzhen1
 
 =over 4
 
@@ -1348,6 +1348,10 @@ Gareth Tunley <gjtunley@gmail.com>
 
 =item *
 
+M Conrad <mike@nrdvana.net>
+
+=item *
+
 Meredith Howard <mhoward@roomag.org>
 
 =item *
